=========================================================================
 Sage: Open Source Mathematics Software: System and software environment
=========================================================================

About SageMath
--------------

   "Creating a Viable Open Source Alternative to
    Magma, Maple, Mathematica, and MATLAB"

   Copyright (C) 2005-2024 The Sage Development Team

   https://www.sagemath.org

SageMath fully supports all major Linux distributions, recent versions of
macOS, and Windows (Windows Subsystem for Linux).

See https://doc.sagemath.org/html/en/installation/index.html
for general installation instructions.


About this pip-installable distribution package
-----------------------------------------------

The pip-installable distribution package `sagemath-environment` is a
distribution of a small part of the Sage Library.

It provides a small, fundamental subset of the modules of the Sage
library ("sagelib", `sagemath-standard`), providing the connection to the
system and software environment.  It also includes the `sage` script for
launching the Sage REPL and accessing various developer tools (see `sage
--help`).
